@@ -13,8 +13,8 @@ public:
 
     QString getAuthorName() {return _authorName;}
     void setAuthorName(QString name) {_authorName = name;}
-    int getAuthorId() {return _authorId;}
-    void setAuthorId(int authorId) {_authorId = authorId;}
+    qint64 getAuthorId() {return _authorId;}
+    void setAuthorId(qint64 authorId) {_authorId = authorId;}
     QString getText() {return _text;}
     void setText(QString text) {_text = text;}
     QDateTime getTimestamp() {return _timestamp;}
@@ -26,7 +26,7 @@ public slots:
 
 private:
     QString _authorName;
-    int _authorId;
+    qint64 _authorId;
     QString _text;
     QDateTime _timestamp;
 
