@@ -13,8 +13,8 @@ public:
     explicit Message(QObject *parent = 0);
     enum MessageType {STATUS,CHECKIN,LINK,POST};
 
-    int getId() {return this->_id;}
-    void setId(int id) {this->_id = id;}
+    qint64 getId() {return this->_id;}
+    void setId(qint64 id) {this->_id = id;}
     MessageType getMessageType() {return this->_messageType;}
     void setMessageType(MessageType messageType) {this->_messageType = messageType;}
 
@@ -37,7 +37,7 @@ private:
     int _id;
     MessageType _messageType;
     QString _authorName;
-    int _authorId;
+    qint64 _authorId;
     QString _text;
     QDateTime _timestamp;
     QList<Comment *> _comments;
