@@ -20,6 +20,8 @@
 
 #include "logindialog.h"
 #include "constants.h"
+#include <QPair>
+#include <QList>
 #include <QVBoxLayout>
 #include <QUrl>
 
@@ -43,7 +45,7 @@ LoginDialog::LoginDialog(QWidget *parent) :
     url.addQueryItem("redirect_uri",AUTH_REDIRECT_URI);
     url.addQueryItem("type","user_agent");
     url.addQueryItem("display","touch");
-    url.addQueryItem("scope","user_status,read_stream,publish_stream,offline_access");
+    url.addQueryItem("scope","user_status,read_stream,publish_stream,user_checkins,publish_checkins,offline_access");
     webView->load(url);}
 
 void LoginDialog::on_page_loaded(QUrl url)
@@ -51,6 +53,33 @@ void LoginDialog::on_page_loaded(QUrl url)
     //parse the url and find the token
     //need to use regex--it is not completely valid!
     if (url.isEmpty()) return;
+    if (url.isValid()) {
+        QList<QPair<QString, QString> >items = url.queryItems();
+        QPair<QString, QString> pair;
+        bool foundError = false;
+        QString error,error_reason,error_description;
+        foreach(pair, items) {
+            if (pair.first=="error")
+            {
+                foundError = true;
+                error = pair.second;
+            }
+            else if (pair.first=="error_reason")
+            {
+                foundError = true;
+                error_reason = pair.second;
+            }
+            else if (pair.first=="error_description")
+            {
+                foundError = true;
+                error_description = pair.second;
+            }
+        }
+        if (foundError) {
+            this->auth_token = "";
+            this->reject();
+        }
+    }
     int pos = re.indexIn(url.toString());
     if (pos<0) return;
     QString token;
